# Heizer

[![PyPI Latest Release](https://img.shields.io/pypi/v/heizer.svg)](https://pypi.org/project/heizer/)
[![Package Status](https://img.shields.io/pypi/status/heizer.svg)](https://pypi.org/project/heizer/)
[![License](https://img.shields.io/pypi/l/heizer.svg)](https://github.com/claudezss/heizer/blob/main/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/heizer?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/heizer)
[![Slack](https://img.shields.io/badge/join_Slack-information-brightgreen.svg?logo=slack)](https://heizer-py.slack.com/archives/C050PE7C597)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)


A python library to easily create kafka producer and consumer

## Install

> Note: Heizer is still in development, so you need to install it with `--pre` flag

```shell
pip install --pre heizer
```

## Setup
Use `docker-compose.yaml` file to start kafka service

```shell
docker-compose up -d
```

## Tutorial And Documentation

http://heizer.claudezss.com

